/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JMXConnectionParam.java 1398 2008-06-10 14:28:31Z renaultgu $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.adapter.jmx.pool.api;

import java.io.Serializable;

import javax.resource.cci.ConnectionSpec;
import javax.resource.spi.ConnectionRequestInfo;

/**
 * The parameters class of the RA. Implements both ConnectionRequestInfo and
 * ConnectionSpec so it can be use in two different ways.
 *
 * @author Guillaume Renault
 *
 */
public class JMXConnectionParam implements ConnectionRequestInfo, Serializable, ConnectionSpec {

    /**
     *
     */
    private static final long serialVersionUID = -8452492298205754796L;

    /**
     * JMX URL to connect to.
     */
    private String urlJMX = null;

    /**
     * User name to use when connecting to JMX.
     */
    private String userJMX = null;

    /**
     * Password to use when connecting to JMX.
     */
    private String passwordJMX = null;

    /**
     * Create an empty parameter object.
     */
    public JMXConnectionParam() {
        this.urlJMX = "";
        this.userJMX = "";
        this.passwordJMX = "";
    }

    /**
     * Create the object, initializing the fields with the given parameters.
     *
     * @param url the JMX url to connect
     * @param user the user name
     * @param password the password
     */
    public JMXConnectionParam(final String url, final String user, final String password) {
        this.urlJMX = url;
        this.userJMX = user;
        this.passwordJMX = password;
    }

    /**
     * Override equals method to compare this object.
     *
     * @param obj other {@link JMXConnectionParam} to compare with.
     *
     * @return true if the two compared objects are the same, false otherwise
     */
    @Override
    public boolean equals(final Object obj) {

        if (obj == null) {
            return false;
        }
        if (obj instanceof JMXConnectionParam) {
            JMXConnectionParam cri = (JMXConnectionParam) obj;

            return (this.urlJMX == cri.urlJMX) && (this.userJMX == cri.userJMX) && (this.passwordJMX == cri.passwordJMX);
        } else {
            return false;
        }

    }

    /**
     * Override hashcode method to have a unique one.
     *
     * @return the computed hashcode
     */
    @Override
    public int hashCode() {
        return (this.urlJMX + ";" + this.userJMX + ";" + this.passwordJMX + ".").hashCode();
    }

    /**
     * Get the JMX url of the context.
     *
     * @return the JMX url of the context
     */
    public String getUrlJMX() {
        return this.urlJMX;
    }

    /**
     * Get the JMX user name of the context.
     *
     * @return the JMX user name of the context
     */
    public String getUserJMX() {
        return this.userJMX;
    }

    /**
     * Get the JMX password of the context.
     *
     * @return the JMX password of the context
     */
    public String getPasswordJMX() {
        return this.passwordJMX;
    }

}
